summaryrefslogtreecommitdiff
path: root/gascop.c
diff options
context:
space:
mode:
authorYuval Adam <yuv.adm@gmail.com>2014-10-11 21:01:45 +0300
committerYuval Adam <yuv.adm@gmail.com>2014-10-11 21:01:45 +0300
commitf46d6e570f2d61aa615e7ec1775527150f5993f6 (patch)
tree40b78521531e2d380d31266b6938275a25ab1a43 /gascop.c
parentabe5d3799a61aba22450da6a295a6742ae1db6b2 (diff)
Fix noise parameters
Diffstat (limited to 'gascop.c')
-rw-r--r--gascop.c11
1 files changed, 6 insertions, 5 deletions
diff --git a/gascop.c b/gascop.c
index ce4cf44..edae045 100644
--- a/gascop.c
+++ b/gascop.c
@@ -50,7 +50,7 @@
#define POCSAG_MAXWORD 16
#define POCSAG_MSG_LEN 256
-#define POCSAG_DEFAULT_RATE 2000000
+#define POCSAG_DEFAULT_RATE 1200000
#define POCSAG_DEFAULT_WIDTH 1000
#define POCSAG_DEFAULT_HEIGHT 700
#define POCSAG_ASYNC_BUF_NUMBER 12
@@ -257,10 +257,11 @@ int main(int argc, char **argv) {
/* Compute the instantaneous phase of the next IQ sample */
nph = atan2(q, i);
- /* Check if we have completed a full circle by jumping phase, usually -3 -> 3 */
- /* Also add a high pass filter, anything less than 10 is noise */
- if ((nph - ph > 3) && (ph_len > 10)){
- printf("Phase jump from %4d to %4d after %4d samples\n", ph, nph, ph_len);
+ /* Check if we have completed a full circle by jumping phase, usually -2/-3 -> 2/3 */
+ /* Also add a high pass filter, anything less than 30 is noise */
+ if ((nph - ph > 3) && (ph_len > 30)) {
+ /* printf("Phase jump from %4d to %4d after %4d samples\n", ph, nph, ph_len); */
+ printf("%d,", ph_len);
ph_len = 0;
}
else {